pandas.Panel
============

.. currentmodule:: pandas

.. autoclass:: Panel

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Panel.abs
      Panel.add
      Panel.add_prefix
      Panel.add_suffix
      Panel.align
      Panel.apply
      Panel.as_blocks
      Panel.as_matrix
      Panel.asfreq
      Panel.astype
      Panel.at_time
      Panel.between_time
      Panel.bfill
      Panel.bool
      Panel.clip
      Panel.clip_lower
      Panel.clip_upper
      Panel.compound
      Panel.conform
      Panel.consolidate
      Panel.convert_objects
      Panel.copy
      Panel.count
      Panel.cummax
      Panel.cummin
      Panel.cumprod
      Panel.cumsum
      Panel.div
      Panel.divide
      Panel.drop
      Panel.dropna
      Panel.eq
      Panel.ffill
      Panel.fillna
      Panel.filter
      Panel.first
      Panel.floordiv
      Panel.fromDict
      Panel.from_dict
      Panel.ge
      Panel.get
      Panel.get_dtype_counts
      Panel.get_ftype_counts
      Panel.get_value
      Panel.get_values
      Panel.groupby
      Panel.gt
      Panel.head
      Panel.interpolate
      Panel.isnull
      Panel.iteritems
      Panel.iterkv
      Panel.join
      Panel.keys
      Panel.kurt
      Panel.kurtosis
      Panel.last
      Panel.le
      Panel.load
      Panel.lt
      Panel.mad
      Panel.major_xs
      Panel.mask
      Panel.max
      Panel.mean
      Panel.median
      Panel.min
      Panel.minor_xs
      Panel.mod
      Panel.mul
      Panel.multiply
      Panel.ne
      Panel.notnull
      Panel.pct_change
      Panel.pop
      Panel.pow
      Panel.prod
      Panel.product
      Panel.radd
      Panel.rdiv
      Panel.reindex
      Panel.reindex_axis
      Panel.reindex_like
      Panel.rename
      Panel.rename_axis
      Panel.replace
      Panel.resample
      Panel.rfloordiv
      Panel.rmod
      Panel.rmul
      Panel.rpow
      Panel.rsub
      Panel.rtruediv
      Panel.save
      Panel.select
      Panel.set_value
      Panel.shift
      Panel.skew
      Panel.sort_index
      Panel.squeeze
      Panel.std
      Panel.sub
      Panel.subtract
      Panel.sum
      Panel.swapaxes
      Panel.swaplevel
      Panel.tail
      Panel.take
      Panel.toLong
      Panel.to_clipboard
      Panel.to_dense
      Panel.to_excel
      Panel.to_frame
      Panel.to_hdf
      Panel.to_json
      Panel.to_long
      Panel.to_msgpack
      Panel.to_pickle
      Panel.to_sparse
      Panel.transpose
      Panel.truediv
      Panel.truncate
      Panel.tshift
      Panel.tz_convert
      Panel.tz_localize
      Panel.update
      Panel.var
      Panel.where
      Panel.xs




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Panel.at
      Panel.axes
      Panel.blocks
      Panel.dtypes
      Panel.empty
      Panel.ftypes
      Panel.iat
      Panel.iloc
      Panel.is_copy
      Panel.ix
      Panel.loc
      Panel.ndim
      Panel.shape
      Panel.values


